/*
 * Awake File: Easy file upload & download through HTTP with Java
 * Awake SQL: Remote JDBC access through HTTP.                                    
 * Copyright (C) 2012, Kawan Softwares S.A.S.
 * (http://www.awakeframework.org). All rights reserved.                                
 *                                                                               
 * Awake File/SQL is free software; you can redistribute it and/or                 
 * modify it under the terms of the GNU Lesser General Public                    
 * License as published by the Free Software Foundation; either                  
 * version 2.1 of the License, or (at your option) any later version.            
 *                                                                               
 * Awake File/SQL is distributed in the hope that it will be useful,               
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             
 * Lesser General Public License for more details.                               
 *                                                                               
 * You should have received a copy of the GNU Lesser General Public              
 * License along with this library; if not, write to the Free Software           
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
 * 02110-1301  USA
 *
 * Any modifications to this file must keep this entire header
 * intact.
 */

//CallUtil.java
//Copyright (c) Kawan Softwares S.A.S, 2012
//
//Last Updates: 
// 17/07/11 14:15 NDP : CallUtil creation & comments 

package org.awakefw.file.servlet.util;

import java.lang.reflect.Type;

/**
 * @author Nicolas de Pomereu
 * 
 */
public class CallUtil {

    /** The class to analyze */
    private Class<?> c = null;

    /**
     * Constructor
     * 
     * @param c
     *            the class to analyze
     */
    public CallUtil(Class<?> c) {
	this.c = c;
    }

    /**
     * Returns true if the class is callable with authentication
     * 
     * @return true if the class is calable with authentication from client side
     * 
     */
    public boolean isCallable() {
	// If it's callable without any authentication, it's OK:
	if (isCallableNotAuthenticated()) {
	    return true;
	}

	boolean callAllowed = false;

	Type[] interfaces = c.getGenericInterfaces();
	if (interfaces.length != 0) {
	    for (Type theInterface : interfaces) {
		// Call is allowed if the class implements the
		// org.awakefw.file.api.server.AwakeCallable
		if (theInterface.toString().endsWith(
			org.awakefw.file.api.server.AwakeCallable.class
				.getName())) {
		    callAllowed = true;
		    break;
		}
	    }
	}
	return callAllowed;
    }

    /**
     * Returns true if the class is callable with authentication
     * 
     * @return true if the class is callable with authentication from client
     *         side
     * 
     */
    public boolean isCallableNotAuthenticated() {
	boolean callAllowed = false;

	Type[] interfaces = c.getGenericInterfaces();
	if (interfaces.length != 0) {
	    for (Type theInterface : interfaces) {
		// Call is allowed if the class implements the
		// org.awakefw.file.api.server.AwakeCallableNotAuthenticated
		// interface
		if (theInterface
			.toString()
			.endsWith(
				org.awakefw.file.api.server.AwakeCallableNoAuth.class
					.getName())) {
		    callAllowed = true;
		}
	    }
	}
	return callAllowed;
    }

}
